@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -2090,7 +2090,8 @@ gkrellmd_load_monitors(void)
 	if (_GK.list_plugins)
 		exit(0);
 	if (_GK.log_plugins)
-		printf("%s\n", plugin_install_log);
+		printf("%s\n", plugin_install_log ? plugin_install_log :
+				_("No plugins found\n"));
 	for (  ; list; list = list->next)
 		{
 		mon = (GkrellmdMonitor *) list->data;
@@ -2163,7 +2164,6 @@ gkrellmd_update_monitors(void)
 			if (!mon->serve_data || (!mp->need_serve && client->served))
 				continue;
 			mp->client = client;
-			mp->serve_name = NULL;
 			mp->serve_name_sent = FALSE;
 			(*(mon->serve_data))(mon, client->served ? FALSE : TRUE);
 			if (mp->serve_gstring->len > 0)
@@ -2276,12 +2276,11 @@ void
 gkrellmd_client_read(gint fd, gint nbytes)
 	{
 	GList					*list;
-	GkrellmdClient			*client;
+	GkrellmdClient			*client = NULL;
 	GkrellmdMonitor			*mon;
 	GkrellmdMonitorPrivate	*mp;
 	gchar					buf[513], *s, *e;
 	gint					n, buflen;
-	static void				(*func)(GkrellmdClient *, gchar *);
 
 	for (list = gkrellmd_client_list; list; list = list->next)
 		{
@@ -2308,12 +2307,13 @@ gkrellmd_client_read(gint fd, gint nbytes)
 		}
 	if (!list)
 		return;
+
 	while (gkrellmd_getline_from_gstring(&client->input_gstring,
 				buf, sizeof(buf) - 1))
 		{
 		if (*buf == '<')
 			{
-			func = NULL;
+			client->input_func = NULL;
 			s = buf + 1;
 			for (list = gkrellmd_monitor_list; list; list = list->next)
 				{
@@ -2323,13 +2323,13 @@ gkrellmd_client_read(gint fd, gint nbytes)
 				e = s + n;
 				if (*e == '>' && !strncmp(mp->serve_name, s, n))
 					{
-					func = mp->client_input_func;
+					client->input_func = mp->client_input_func;
 					break;
 					}
 				}
 			}
-		else if (func)
-			(*func)(client, buf);
+		else if (client->input_func)
+			(*client->input_func)(client, buf);
 //		printf("%s: %s", client->hostname, buf);
 		}
 	}
