@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -508,6 +508,7 @@ gkrellm_alert_set_triggers(GkrellmAlert *alert,
 	alert->check_hardwired = TRUE;
 	}
 
+
 void
 gkrellm_alert_commands_config(GkrellmAlert *alert,
 						gboolean alarm, gboolean warn)
