@@ -1,7 +1,7 @@
 /*
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -81,7 +81,7 @@ static GkrellmAlert		*bat_alert;		/* One alert dupped for each battery */
 
 static gint				style_id;
 
-static gboolean			alert_units_are_percent,
+static gboolean			alert_units_percent,
 						alert_units_need_estimate_mode;
 
 static void		(*read_battery_data)();
@@ -479,7 +479,7 @@ update_battery_panel(Battery *bat)
 			)
 			{
 			gkrellm_thaw_alert(bat->alert);
-			gkrellm_check_alert(bat->alert, alert_units_are_percent
+			gkrellm_check_alert(bat->alert, alert_units_percent
 						? bat->percent : bat->time_left);
 			}
 		gkrellm_draw_decal_pixmap(p, bat->power_decal, D_MISC_BATTERY);
@@ -779,7 +779,7 @@ dup_battery_alert(void)
   |  creates from load config will have units in effect at last save config.
   */
 static void
-create_alert(gboolean using_percent)
+create_alert(void)
 	{
 	Battery	*bat;
 
@@ -789,16 +789,17 @@ create_alert(gboolean using_percent)
 
 	if (!bat_alert)
 		{
-		alert_units_are_percent = alert_units_need_estimate_mode = FALSE;
+		alert_units_need_estimate_mode = FALSE;
 
-		if (   using_percent
+		if (   alert_units_percent
 			|| (bat->time_left == -1 && !enable_estimate)
 		   )
 			{
+			if (bat->time_left == -1)
+				alert_units_percent = TRUE;
 			bat_alert = gkrellm_alert_create(NULL, _("Battery"),
 					_("Battery Percent Limits"),
 					FALSE, TRUE, TRUE, 99, 0, 1, 10, 0);
-			alert_units_are_percent = TRUE;
 			}
 		else
 			{
@@ -844,7 +845,7 @@ save_battery_config(FILE *f)
 		fprintf(f, "%s tooltip_comment %s\n",
 					BAT_CONFIG_KEYWORD, launch.tooltip_comment);
 	fprintf(f, "%s alert_units_percent %d\n", BAT_CONFIG_KEYWORD,
-				alert_units_are_percent);
+				alert_units_percent);
 	for (list = battery_list; list; list = list->next)
 		{
 		bat = (Battery *) list->data;
@@ -865,7 +866,6 @@ load_battery_config(gchar *arg)
 	gint			display_mode, n = 0;
 	gchar			config[32], item[CFG_BUFSIZE],
 					name[CFG_BUFSIZE], item1[CFG_BUFSIZE];
-	static gboolean	using_percent;
 
 	if (sscanf(arg, "%31s %[^\n]", config, item) == 2)
 		{
@@ -902,14 +902,14 @@ load_battery_config(gchar *arg)
 				bat->display_mode = display_mode;
 			}
 		else if (!strcmp(config, "alert_units_percent"))
-			sscanf(item, "%d", &using_percent);
+			sscanf(item, "%d", &alert_units_percent);
 		else if (!strcmp(config, GKRELLM_ALERTCONFIG_KEYWORD))
 			{
 			if (!strncmp(item, "BAT", 3))	/* Config compat musical chairs */
 				sscanf(item, "%32s %[^\n]", name, item1);
 			else
 				strcpy(item1, item);
-			create_alert(using_percent);
+			create_alert();
 			gkrellm_load_alertconfig(&bat_alert, item1);
 			dup_battery_alert();
 			}
@@ -940,10 +940,33 @@ update_battery_panels(void)
 static void
 cb_set_alert(GtkWidget *button, Battery *bat)
 	{
-	create_alert(FALSE);
+	create_alert();
 	gkrellm_alert_config_window(&bat_alert);
 	}
 
+static void
+alert_units_percent_cb(GtkToggleButton *button, gpointer data)
+	{
+	GList	*list;
+	Battery	*bat;
+
+	alert_units_percent = button->active;
+
+	if (bat_alert)
+		{
+		for (list = battery_list; list; list = list->next)
+			{
+			bat = (Battery *) list->data;
+			gkrellm_reset_alert(bat->alert);
+			gkrellm_alert_destroy(&bat->alert);
+			}
+		gkrellm_alert_destroy(&bat_alert);
+		gkrellm_config_message_dialog(_("GKrellM Battery"),
+				_("The Battery alert units are changed\n"
+				  "and the alert must be reconfigured."));
+		}
+	}
+
 static void
 cb_enable_estimate(GtkToggleButton *button, GtkWidget *box)
 	{
@@ -965,7 +988,10 @@ cb_enable_estimate(GtkToggleButton *button, GtkWidget *box)
 			if (bat->alert && (!enable && alert_units_need_estimate_mode))
 				gkrellm_alert_destroy(&bat->alert);
 			}
-		if (bat_alert && (!enable && alert_units_need_estimate_mode))
+		if (   bat_alert
+		    && (!enable && alert_units_need_estimate_mode)
+		    && !alert_units_percent
+		   )
 			{
 			gkrellm_alert_destroy(&bat_alert);
 			gkrellm_config_message_dialog(_("GKrellM Battery"),
@@ -1115,6 +1141,7 @@ create_battery_tab(GtkWidget *tab_vbox)
 	{
 	GtkWidget	*tabs, *table, *vbox, *vbox1, *vbox2,
 				*hbox, *hbox2, *text;
+	Battery		*bat;
 	gint		i;
 
 	tabs = gtk_notebook_new();
@@ -1187,6 +1214,16 @@ create_battery_tab(GtkWidget *tab_vbox)
 	gkrellm_gtk_alert_button(hbox, NULL, FALSE, FALSE, 4, TRUE,
 				cb_set_alert, NULL);
 
+	if (battery_list)
+		{
+		bat = (Battery *) battery_list->data;
+		if (bat && bat->time_left >= 0)		/* No choice if no battery times */
+			gkrellm_gtk_check_button_connected(hbox, NULL,
+					alert_units_percent, FALSE, FALSE, 16,
+					alert_units_percent_cb, NULL,
+					_("Alerts check for percent capacity remaining."));
+		}
+
 	vbox1 = gkrellm_gtk_framed_vbox_end(vbox, _("Launch Commands"),
 			4, FALSE, 0, 2);
 	table = gkrellm_gtk_launcher_table_new(vbox1, 1);
