@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -708,7 +708,7 @@ void
 gkrellm_place_plugin(GList **monitor_list, GkrellmMonitor *plugin)
 	{
 	GkrellmMonitor	*mon;
-	GList			*list, *plist;
+	GList			*list, *plist, *waste;
 	gint			n, gravity, after_flag;
 	gchar			buf[120];
 
@@ -761,7 +761,7 @@ gkrellm_place_plugin(GList **monitor_list, GkrellmMonitor *plugin)
 				if (list == *monitor_list)
 					*monitor_list = g_list_prepend(list, plugin);
 				else
-					g_list_prepend(list, plugin);
+					waste = g_list_prepend(list, plugin);
 				}
 			return;
 			}
