@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -131,7 +131,8 @@ linux_read_proc_stat(void)
 	static FILE	*f;
 	gint		n, i, ncpu;
 	gchar		*s, buf[1024];
-	gulong		rblk[4], wblk[4], user, nice, sys, idle, iowait;
+	gulong		rblk[4], wblk[4];
+	guint64		user, nice, sys, idle, iowait;
 	static gint	data_read_tick	= -1;
 
 	n = gkrellm_get_timer_ticks();
@@ -149,7 +150,7 @@ linux_read_proc_stat(void)
 		{
 		if (buf[0] == 'c' && buf[1] == 'p')
 			{
-			n = sscanf(buf, "%*s %lu %lu %lu %lu %lu",
+			n = sscanf(buf, "%*s %Lu %Lu %Lu %Lu %Lu",
 						&user, &nice, &sys, &idle, &iowait);
 
 			if (n == 5)			/* iowait is new in kernel 2.5	*/
@@ -522,7 +523,7 @@ static void
 linux_read_proc_diskstats(void)
 	{
 	static FILE		*f;
-	gchar			buf[1024], part[64], disk[64];
+	gchar			buf[1024], part[128], disk[128];
 	gint			major, minor, n;
 	gulong			rd, wr, rd1, wr1;
 	gboolean		inactivity_override, is_MD;
@@ -541,7 +542,7 @@ linux_read_proc_diskstats(void)
 		|  --or for a partition--
 		|  major minor name rio rsect wio wsect
 		*/
-		n = sscanf(buf, "%d %d %64s %*d %lu %lu %lu %*d %*d %lu",
+		n = sscanf(buf, "%d %d %127s %*d %lu %lu %lu %*d %*d %lu",
 					&major, &minor, part, &rd, &rd1, &wr, &wr1);
 		if (n == 7)
 			{
@@ -586,7 +587,7 @@ static void
 linux_read_proc_partitions_or_sysfs(void)
 	{
 	FILE		*f, *sf;
-	gchar		buf[1024], part[64], disk[64], sysfspath[128];
+	gchar		buf[1024], part[128], disk[128], sysfspath[256];
 	gint		major, minor, n;
 	gulong		sectors, rd, wr;
 	gboolean	is_MD;
@@ -606,7 +607,7 @@ linux_read_proc_partitions_or_sysfs(void)
 				/* major minor  #blocks  name
 				|  rio rmerge rsect ruse wio wmerge wsect wuse running use aveq
 				*/
-				n = sscanf(buf, "%d %d %lu %64s %*d %*d %lu %*d %*d %*d %lu",
+				n = sscanf(buf, "%d %d %lu %127s %*d %*d %lu %*d %*d %*d %lu",
 							&major, &minor, &sectors, part, &rd, &wr);
 				if (   n < 6 || sectors <= 1 || major == LVM_BLK_MAJOR
 					|| !disk_get_device_name(major, minor, disk, part)
@@ -615,7 +616,7 @@ linux_read_proc_partitions_or_sysfs(void)
 				}
 			if (have_sysfs_stats)
 				{
-				n = sscanf(buf, "%d %d %lu %64s",
+				n = sscanf(buf, "%d %d %lu %127s",
 							&major, &minor, &sectors, part);
 				if (   n < 4 || sectors <= 1 || major == LVM_BLK_MAJOR
 					|| !disk_get_device_name(major, minor, disk, part)
@@ -1111,12 +1112,12 @@ gkrellm_sys_mem_read_data(void)
 	FILE		*f;
 	gchar		buf[160];
 	gboolean	using_tagged = FALSE;
-	guint64		total, used, x_used, free, shared, buffers, cached;
+	guint64		total, used, x_used, free, shared, buffers, cached, slab;
 
 	/* Default  0, so we don't get arbitrary values if not found,
 	|  e.g. MemShared is not present in 2.6.
 	*/
-	total = used = x_used = free = shared = buffers = cached = 0LL;
+	total = used = x_used = free = shared = buffers = cached = slab = 0LL;
 
 	if ((f = fopen(PROC_MEMINFO_FILE, "r")) == NULL)
 		return;
@@ -1146,6 +1147,8 @@ gkrellm_sys_mem_read_data(void)
 				tagged_format_meminfo(buf + 11, &swap_total);
 			else if (!strncmp(buf, "SwapFree:", 9))
 				tagged_format_meminfo(buf + 10, &swap_used);
+			else if (!strncmp(buf, "Slab:", 5))
+				tagged_format_meminfo(buf + 6, &slab);
 			}
 		else if (buf[0] == 'B' && !strncmp(buf, "Buffers:", 8))
 			tagged_format_meminfo(buf + 9, &buffers);
@@ -1158,8 +1161,8 @@ gkrellm_sys_mem_read_data(void)
 		x_used = total - free;
 		swap_used = swap_total - swap_used;
 		}
-	used = x_used - buffers - cached;
-	gkrellm_mem_assign_data(total, used, free, shared, buffers, cached);
+	used = x_used - buffers - cached - slab;
+	gkrellm_mem_assign_data(total, used, free, shared, buffers, cached + slab);
 	}
 
   /* Kernel >= 2.6 swap page in/out is in /proc/vmstat.
@@ -1269,7 +1272,7 @@ gkrellm_sys_fs_get_fstab_list(void)
 	{
 	FILE	*f;
 	gchar	buf[1024], *s;
-	gchar	dev[64], dir[128], type[64], opt[128];
+	gchar	dev[512], dir[512], type[128], opt[256];
 
 	if ((f = fopen("/etc/fstab", "r")) == NULL)
 		return;
@@ -1281,7 +1284,7 @@ gkrellm_sys_fs_get_fstab_list(void)
 		if (*s == '\0' || *s == '#' || *s == '\n')
 			continue;
 		dev[0] = dir[0] = type[0] = opt[0] = '\0';
-		sscanf(s, "%64s %128s %64s %128s", dev, dir, type, opt);
+		sscanf(s, "%511s %511s %127s %255s", dev, dir, type, opt);
 		fix_fstab_name(dev);
 		fix_fstab_name(dir);
 		fix_fstab_name(type);
@@ -1325,13 +1328,13 @@ void
 gkrellm_sys_fs_get_mounts_list(void)
 	{
 	FILE		*f;
-	gchar		*s, buf[128], dev[64], dir[128], type[32];
+	gchar		*s, buf[512], dev[256], dir[256], type[64];
 
 	if ((f = fopen(PROC_MOUNTS_FILE, "r")) == NULL)
 		return;
 	while (fgets(buf, sizeof(buf), f))
 		{
-		sscanf(buf, "%63s %127s %31s", dev, dir, type);
+		sscanf(buf, "%255s %255s %63s", dev, dir, type);
 		if (   !strcmp(type, "devpts")
 			|| !strcmp(type, "proc")
 			|| !strcmp(type, "usbdevfs")
@@ -1595,8 +1598,8 @@ acpi_battery_data(BatteryFile *bf)
 			{
 			/*	state: {on-line|off-line}
 			*/
-			if (   (   sscanf (buf, "state: %s", s1) == 1
-					|| sscanf (buf, "status: %s", s1) == 1
+			if (   (   sscanf (buf, "state: %31s", s1) == 1
+					|| sscanf (buf, "status: %31s", s1) == 1
 				   )
 				&& !strcmp(s1, "on-line")
 			   )
@@ -1619,7 +1622,7 @@ acpi_battery_data(BatteryFile *bf)
 		|	remaining capacity:	31282 mWh
 		|	present voltage:	16652 mV
 		*/
-		if (sscanf(buf, "charging state: %s", s1) == 1)
+		if (sscanf(buf, "charging state: %31s", s1) == 1)
 			{
 			have_charging_state = TRUE;
 			if (   (!strcmp(s1, "unknown") && on_line)
@@ -1636,7 +1639,7 @@ acpi_battery_data(BatteryFile *bf)
 			}
 		if (sscanf(buf, "present rate: %d", &cur_rate) == 1)
 			continue;
-		if (   sscanf(buf, "present: %s", s1) == 1
+		if (   sscanf(buf, "present: %31s", s1) == 1
 			&& !strcmp(s1, "yes")
 		   )
 			available = TRUE;
@@ -1795,7 +1798,7 @@ apm_battery_data(void)
 		return FALSE;
 	fgets(buf, sizeof(buf), f);
 
-	sscanf(buf, "%*s %d.%d %*x %x %x %x %d%% %d %32s\n",
+	sscanf(buf, "%*s %d.%d %*x %x %x %x %d%% %d %31s\n",
 				&bios_major, &bios_minor,
 				&ac_line_status, &battery_status, &battery_flag,
 				&percent, &time_left, units);
@@ -1815,7 +1818,7 @@ apm_battery_data(void)
 					battery_status, battery_flag, percent, time_left, units);
 		while (n_batteries-- > 0 && fgets(buf, sizeof(buf), f))
 			{
-			sscanf(buf, "%d %x %x %d%% %d %32s\n", &id,
+			sscanf(buf, "%d %x %x %d%% %d %31s\n", &id,
 					&battery_status, &battery_flag,
 					&percent, &time_left, units);
 			apm_battery_assign(id - 1, bios_major, bios_minor, ac_line_status,
@@ -1885,6 +1888,7 @@ gkrellm_sys_uptime_init(void)
 #define	THERMAL_DIR			"/proc/acpi/thermal"
 #define	SENSORS_DIR			"/proc/sys/dev/sensors"
 #define SYSFS_I2C_DIR		"/sys/bus/i2c/devices"
+#define UNINORTH_DIR       "/sys/devices/temperatures"
 
   /* mbmon and hddtemp sensor interfaces are handled in sensors-common.c
   */
@@ -1893,6 +1897,7 @@ gkrellm_sys_uptime_init(void)
 #define	THERMAL_ZONE_INTERFACE		2
 #define	NVIDIA_SETTINGS_INTERFACE	3
 #define IBM_ACPI_INTERFACE		4
+#define UNINORTH_INTERFACE    5
 
 #define IBM_ACPI_FAN_FILE	"/proc/acpi/ibm/fan"
 #define IBM_ACPI_THERMAL	"/proc/acpi/ibm/thermal"
@@ -2038,7 +2043,7 @@ gkrellm_sys_sensors_get_temperature(gchar *sensor_path, gint id,
 		gint iodev, gint interface, gfloat *temp)
 	{
 	FILE		*f;
-	gchar		buf[64], units[32];
+	gchar		buf[128], units[32];
 	gint		n;
 	gfloat		T, t[5], ibm_acpi_temp[8];
 	gboolean	result = FALSE;
@@ -2126,6 +2131,16 @@ gkrellm_sys_sensors_get_temperature(gchar *sensor_path, gint id,
 #endif
 		}
 
+    if (interface == UNINORTH_INTERFACE)
+        {
+        if ((f = fopen(sensor_path, "r")))
+            {
+            fscanf(f, "%f", temp);
+            fclose(f);
+            return TRUE;
+            }
+        }
+
 	if ((f = fopen(sensor_path, "r")) == NULL)
 		return FALSE;
 	fgets(buf, sizeof(buf), f);
@@ -2554,6 +2569,35 @@ gkrellm_sys_sensors_init(void)
 					1.0, 0.0, NULL, "GPU A");
 		}
 
+    if ((dir = g_dir_open(UNINORTH_DIR, 0, NULL)) != NULL)
+        {
+        while (( sensor_name = (gchar *) g_dir_read_name(dir)) != NULL )
+            {
+            if (strncmp(sensor_name, "sensor", 6) == 0)
+                {
+                sensor_path = g_build_filename(UNINORTH_DIR, sensor_name, NULL);
+                if (strncmp(sensor_name + 8, "temperature", 11) == 0)
+                    {
+                    // linux <= 2.6.12 had [cg]pu_temperature instead of
+                    // sensor[12]_temperature
+                    
+                    // TODO: read sensorN_location instead of fixed positions
+                    if (sensor_name[6] == '1' || (strncmp(sensor_name, "cpu", 3)) == 0)
+                        gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE, sensor_path,
+                                "cpu topside", id, 0, UNINORTH_INTERFACE,
+                                1.0, 0.0, NULL, "CPU");
+                    else if (sensor_name[6] == '2' || (strncmp(sensor_name, "gpu", 3)) == 0) 
+                        gkrellm_sensors_add_sensor(SENSOR_TEMPERATURE, sensor_path,
+                                "gpu on die", id, 0, UNINORTH_INTERFACE,
+                                1.0, 0.0, NULL, "GPU");
+                    }
+                g_free(sensor_path);
+                }
+            }
+        g_dir_close(dir);
+        }
+
+
 	if ((dir = g_dir_open(SENSORS_DIR, 0, NULL)) == NULL)
 		{
 		sysfs_sensors_init();
