@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  OpenBSD code derived from FreeBSD code by: Hajimu UMEMOTO <ume@FreeBSD.org>
