@@ -1,7 +1,7 @@
 /* GKrellM
-|  Copyright (C) 1999-2005 Bill Wilson
+|  Copyright (C) 1999-2006 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
 |  This program is free software which I release under the GNU General Public
@@ -255,11 +255,17 @@ static FILE		*f_lock;
 static gboolean
 _gkrellm_get_lock(void)
 	{
-	gchar	*lock_file, *display, *s;
+	gchar	*lock_dir, *lock_file, *display, *s;
+	gchar	buf[32];
+
+	snprintf(buf, sizeof(buf), "LCK..%d", (gint) getuid());
 
 #if defined(F_TLOCK)
-	lock_file = gkrellm_make_config_file_name(gkrellm_homedir(),
-					GKRELLM_LOCK_FILE);
+	lock_dir = "/var/lock/gkrellm";
+	if (!g_file_test(lock_dir, G_FILE_TEST_IS_DIR))
+		mkdir(lock_dir, 0755);
+
+	lock_file = gkrellm_make_config_file_name(lock_dir, buf);
 	display = XDisplayName(NULL);
 	if (display)
 		{
@@ -274,6 +280,11 @@ _gkrellm_get_lock(void)
 		&& errno == EAGAIN
 	   )
 		return FALSE;
+	if (f_lock)
+		{
+		fprintf(f_lock, "%10d\n", (gint) getpid());
+		fflush(f_lock); 
+		}
 #endif
 	return TRUE;
 	}
@@ -444,7 +455,8 @@ gkrellm_winop_place_gkrellm(gchar *geom)
 	gint	place, x, y, w_gkrell, h_gkrell;
 
 	x = y = 0;
-	place = XParseGeometry(geom, &x, &y, &w_gkrell, &h_gkrell);
+	place = XParseGeometry(geom, &x, &y,
+				(guint *) &w_gkrell, (guint *) &h_gkrell);
 
 	w_gkrell = _GK.chart_width + _GK.frame_left_width + _GK.frame_right_width;
 	h_gkrell = _GK.monitor_height + _GK.total_frame_height;
@@ -665,8 +677,8 @@ gkrellm_winop_apply_rootpixmap_transparency(void)
 	gulong			nitems, bytes_after;
 	gint			depth_visual;
 	Window			root_return;
-	guint			x_ret, y_ret, w_ret, h_ret, bw_ret, depth_ret;
-	gint			x_root, y_root;
+	guint			w_ret, h_ret, bw_ret, depth_ret;
+	gint			x_ret, y_ret, x_root, y_root;
 
 	if (!_GK.any_transparency)
 		return;
